@@ -42,7 +42,7 @@ describe 'sahara::client' do
       end
 
       let(:platform_params) do
-        case facts[:osfamily]
+        case facts[:os]['family']
         when 'Debian'
           { :client_package_name => 'python3-saharaclient' }
         when 'RedHat'
